[![PyPI package build](https://github.com/caravagnalab/pyLineaGT/actions/workflows/python-publish.yml/badge.svg)](https://github.com/caravagnalab/pyLineaGT/actions)

# pyLineaGT

A set of Pyro model and functions to perform lineage inference from Gene Therapy assays, enclosed in a `Python` package. \
It comes with an [`R` package](https://github.com/caravagnalab/LineaGT), used as interface to perform data pre-processing and visualize the inference results.

## To install

`$ pip install pylineaGT`
